// Persistence of Vision Ray Tracer Scene Description File
// File: iso_csg_test11.pov
// Vers: 3.5
// Desc: iso_csg torus macros demo
// Date: Jun. 2003
// Auth: Christoph Hormann
//

// ----------------------------------------

#version 3.5;

global_settings {
  assumed_gamma 1
}

background { color <0.750,0.500,0.300> }

camera {
  location <0.6,0.7,-1>*4
  look_at  <0.16,0,0>
  right (4/3)*x
  angle 36
}

light_source {
  <1000, 3500, -5000>
  color rgb 1.2
}

#include "iso_rcsg.inc"

#declare fn_YY=IC_Intersection2(IC_Torus(0.15, 0.05), IC_Plane(<-1, 0, 1>, 0))

#declare fn_ZZ=
  function {
    pattern {
      radial
      sine_wave
      frequency 12
    }
  }


// ----------------------------------------

#declare fn_XX=IC_Shaped_Fan(function { fn_YY(x, z, y) }, 0.5, 220)

isosurface {

  function{ fn_XX(x, y, z)-fn_ZZ(x, y, z)*0.05 }

  max_gradient 3

  accuracy 0.001
  contained_by { box { <-0.7, -0.25, -0.7>, <0.7, 0.22, 0.7> } }


  texture {
    pigment { rgb <1.1, 0.2, 0> }
    finish {
      specular 0.15
    }
  }

  translate x+0.4*y
}

#undef fn_XX

#declare fn_XX=IC_Fan(0.5, 0.1, 220)

isosurface {

  function{ fn_XX(x, y, z)-fn_ZZ(x, y, z)*0.05 }

  max_gradient 3

  accuracy 0.001
  contained_by { box { <-0.7, -0.25, -0.7>, <0.7, 0.22, 0.7> } }


  texture {
    pigment { rgb <1.1, 0.2, 0> }
    finish {
      specular 0.15
    }
  }

  translate -x+0.4*y
}

#undef fn_XX

// ----------------------------------------

#local Ang=0;

#while (Ang<360)

  #declare fn_XX=IC_Shaped_Arc(function { fn_YY(x, z, y) }, 0.5, Ang, Ang+24)

  isosurface {

    function{ fn_XX(x, y, z) }

    max_gradient 3

    accuracy 0.001
    contained_by { box { <-0.7, -0.25, -0.7>, <0.7, 0.22, 0.7> } }


    texture {
      pigment { rgb <0, 0.2, 1.1> }
      finish {
        specular 0.15
      }
    }

    translate x
  }

  #undef fn_XX

  #declare fn_XX=IC_Arc(0.5, 0.2, Ang, Ang+24)

  isosurface {

    function{ fn_XX(x, y, z) }

    max_gradient 3

    accuracy 0.001
    contained_by { box { <-0.7, -0.25, -0.7>, <0.7, 0.22, 0.7> } }


    texture {
      pigment { rgb <0, 0.2, 1.1> }
      finish {
        specular 0.15
      }
    }

    translate -x
  }

  #undef fn_XX

  #local Ang=Ang+30;

#end

// ----------------------------------------

plane {
  y, -0.35
  texture {
    pigment { rgb <1, 0.78, 0.7> }
  }
}


